# flutter_dipnav

Advanced navigation based on Navigator 2.0

+ **Simple use**
+ **Easy integration**
+ **Lots of possibilities**

## Using

#### Go to the next route

```dart
context.dipNav.push(
    path: '/',
    page: MyHomePage(title: 'Home Page'));
```

#### Go to the previous route

```dart
context.dipNav.pop();
```

## Getting Started

##### 1) Add dependency

```yaml
dependencies:
  ...
  flutter_dipnav: ^1.0.0-dev.3
```

##### 2) Create instance of [DipNavRouter], like this

```dart
final dipNav = DipNavRouter(
  initRoute: DipNavRoute(
      page: '/',
      child: MyHomePage(
        title: 'Home Page 1',
      )),
  notFoundRoute: DipNavRoute(
      path: '/404',
      page: MyHomePage(
        title: 'Error 404 - Not found page',
      )),
);
```

##### 3) Add the [DipNav] widget to the source, like this

```dart
class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    ...
    return DipNav(
      router: dipNav,
      child: MaterialApp.router(
        ...
      ),
    );
  }
}
```

##### 4) Add the [routerDelegate], [routeInformationParser] and [backButtonDispatcher] to the [MaterialApp.router]

```dart
child: MaterialApp.router(
    title: 'Flutter Demo',
    ...
    routerDelegate: dipNav.delegate,
    routeInformationParser: dipNav.parser,
    backButtonDispatcher: dipNav.dispatcher,
),
```

###### Please check the [example][example]

[example]: https://gitlab.com/dipdev.studio/open-source/flutter/flutter-dipnav/-/tree/master/example

## Features and bugs

> Please file feature requests and bugs at the [issue tracker][tracker].

[tracker]: https://gitlab.com/dipdev.studio/open-source/flutter/flutter-dipnav/-/issues

## Authors

> This project developed by [**DipDev Studio**](https://dipdev.studio) Team: [@Dimoshka](https://www.linkedin.com/in/dmytroprylutskyi/)
