import 'package:flutter/material.dart';
import 'package:flutter_dipnav/flutter_dipnav.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final dipNav = DipNavRouter(
      initRoute: DipNavRoute(
          path: '/',
          page: MyHomePage(
            title: 'Home Page 1',
          )),
      notFoundRoute: DipNavRoute(
          path: '/404',
          page: MyHomePage(
            title: 'Error 404 - Not found page',
          )),
    );
    return DipNav(
      router: dipNav,
      child: MaterialApp.router(
        title: 'Flutter Demo',
        theme: ThemeData(
          primarySwatch: Colors.blue,
        ),
        routerDelegate: dipNav.delegate,
        routeInformationParser: dipNav.parser,
        backButtonDispatcher: dipNav.dispatcher,
      ),
    );
  }
}

class MyHomePage extends StatelessWidget {
  final String title;

  const MyHomePage({Key? key, required this.title}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final args = ModalRoute.of(context)?.settings.arguments;
    return Scaffold(
      appBar: AppBar(
        title: Text(title),
      ),
      body: Center(
          child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          if (args != null) Text('$args'),
          TextButton(
              onPressed: () => context.dipNav.pop(),
              child: Text('Previous page')),
          TextButton(
              onPressed: () => context.dipNav.push(
                  path: '/page3',
                  queries: {'type': 'replaced'},
                  page: MyHomePage(title: 'Home Page 3'),
                  replaceCurrent: true),
              child: Text('Replace page')),
          TextButton(
              onPressed: () => context.dipNav.push(
                  path: '/page4',
                  queries: {'type': 'cleaned_stack'},
                  page: MyHomePage(title: 'Home Page 4'),
                  removeUntil: true),
              child: Text('Remove until new page')),
          TextButton(
              onPressed: () => context.dipNav
                  .push(path: '/page2', page: MyHomePage(title: 'Home Page 2')),
              child: Text('Next page')),
        ],
      )),
    );
  }
}
