import 'package:flutter/material.dart';
import 'package:flutter_dipnav/src/dip_nav_route.dart';

part 'dip_nav_delegate.dart';
part 'dip_nav_dispatcher.dart';
part 'dip_nav_parser.dart';
part 'dip_nav_resultable_page.dart';

/// Main class of routing based on Navigator 2.0.
class DipNavRouter {
  late _DipNavDelegate _delegate;
  late _DipNavParser _parser;
  late _DipNavDispatcher _dispatcher;

  /// {@macro flutter_dipnav._DipNavDelegate}
  _DipNavDelegate get delegate => _delegate;

  /// {@macro flutter_dipnav._DipNavParser}
  _DipNavParser get parser => _parser;

  /// {@macro flutter_dipnav._DipNavDispatcher}
  _DipNavDispatcher get dispatcher => _dispatcher;

  /// {@macro flutter_dipnav._DipNavRouter.routes}
  List<DipNavRoute> get routes => List.of(_delegate.routes);

  /// {@macro flutter_dipnav._DipNavRouter.initRoute}
  DipNavRoute get initRoute => _delegate.initRoute;

  /// {@macro flutter_dipnav._DipNavRouter.notFoundRoute}
  DipNavRoute? get notFoundRoute => _delegate.notFoundRoute;

  DipNavRouter({required DipNavRoute initRoute, DipNavRoute? notFoundRoute}) {
    _delegate =
        _DipNavDelegate(initRoute: initRoute, notFoundRoute: notFoundRoute);
    _parser = _DipNavParser(this);
    _dispatcher = _DipNavDispatcher(this);
  }

  /// Push method of adding new route
  Future<T?> push<T>(
      {String? key,
      required String path,
      Map<String, dynamic>? queries,
      required Widget page,
      final Object? arguments,
      bool removeUntil = false,
      bool replaceCurrent = false}) async {
    return _delegate.pushRoute(
        DipNavRoute(
            key: key,
            path: path,
            queries: queries,
            page: page,
            arguments: arguments),
        removeUntil: removeUntil,
        replaceCurrent: replaceCurrent);
  }

  /// Pop method for return to previous route
  Future<bool> pop<T>({T? arguments}) {
    return _delegate.popRoute();
  }
}
